# tegregr

This is a function that runs a multiple regression analysis and provides the F-test for explained variance of the overall model and t-tests per coefficient. The function also lets you test significance of additional explained variance of a set of predictors added to a baseline model.